<?php

App::uses('CakeEventListener', 'Event');

class EvBasketBasketTotalsCalculation implements CakeEventListener {

	public function implementedEvents() {
		return array(
			'EvBasket.Component.Basket.itemAdd' => array(
				'callable' => 'calculateTotals',
				'priority' => 10
			),
			'EvBasket.Component.Basket.itemUpdated' => array(
				'callable' => 'calculateTotals',
				'priority' => 10
			),
			'EvBasket.Component.Basket.itemDeleted' => array(
				'callable' => 'calculateTotals',
				'priority' => 10
			)
		);
	}

	/**
	 * calculate the totals extra totals.
	 * sub totals / tax / delivery placeholder (if set)
	 *
	 * @param 	Object 	$Event 	Cake Event
	 * @return
	 */
	public function calculateTotals(CakeEvent $Event) {
		$Event->subject()->getBasket(true);

		// process subtotal
		// process Tax
		$subtotal = 0;
		$tax = 0;
		$BasketItems = $Event->subject()->basketCache['BasketItem'];

		foreach ($BasketItems as $BasketItem) {
			$subtotal += $BasketItem['row_total'];
			$tax += $BasketItem['row_tax_amount'];
		}

		$deliveryPlaceholder = Configure::read('EvBasket.deliveryPlaceholder');
		if ($deliveryPlaceholder !== false) {
			// add / update the tax row
			$Event->subject()->manageTotalRow(
				Configure::read('EvBasket.labels.delivery'),
				$deliveryPlaceholder,
				20,
				false
			);

			// check with ash - add 20% tax rate
			$delTax = ((20 / 100) * $deliveryPlaceholder);
			$tax += $delTax;
		}

		// add / update the subtotal row
		$Event->subject()->manageTotalRow(
			Configure::read('EvBasket.labels.subtotal'),
			$subtotal,
			10,
			true
		);

		// add / update the tax row
		$Event->subject()->manageTotalRow(
			Configure::read('EvBasket.labels.tax'),
			$tax,
			30,
			false
		);

		return true;
	}
}